@@ -1,13 +1,10 @@
-#ifndef lint
-static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/colors.c,v 1.12 1998/05/25 02:36:33 sopwith Exp $";
-#endif
 /*****
 * colors.c : XmHTML color allocation routines
 *
-* This file Version	$Revision: 1.12 $
+* This file Version	$Revision: 1.13 $
 *
 * Creation date:		Mon Dec 16 13:57:41 GMT+0100 1996
-* Last modification: 	$Date: 1998/05/25 02:36:33 $
+* Last modification: 	$Date: 1999/07/29 01:26:28 $
 * By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
@@ -35,6 +32,11 @@ static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/colors
 /*****
 * ChangeLog 
 * $Log: colors.c,v $
+* Revision 1.13  1999/07/29 01:26:28  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.12  1998/05/25 02:36:33  sopwith
 *
 *
