@@ -17,11 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* Render a sorted vector path into an RGB buffer. */
-
 #ifndef __ART_RGB_SVP_H__
 #define __ART_RGB_SVP_H__
 
+/* Render a sorted vector path into an RGB buffer. */
+
+#include <libart_lgpl/art_alphagamma.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -30,13 +32,15 @@ void
 art_rgb_svp_aa (const ArtSVP *svp,
 		int x0, int y0, int x1, int y1,
 		art_u32 fg_color, art_u32 bg_color,
-		art_u8 *buf, int rowstride);
+		art_u8 *buf, int rowstride,
+		ArtAlphaGamma *alphagamma);
 
 void
 art_rgb_svp_alpha (const ArtSVP *svp,
 		   int x0, int y0, int x1, int y1,
 		   art_u32 rgba,
-		   art_u8 *buf, int rowstride);
+		   art_u8 *buf, int rowstride,
+		   ArtAlphaGamma *alphagamma);
 
 #ifdef __cplusplus
 }
