@@ -96,7 +96,7 @@ static void                update                  (GnomeAnimator *animator);
 static GnomeAnimatorFrame *append_frame            (GnomeAnimator *animator);
 static void                state_or_style_changed  (GnomeAnimator *animator);
 static void                state_changed           (GtkWidget *widget,
-                                                    guint previous_state);
+                                                    GtkStateType previous_state);
 static void                style_set               (GtkWidget *widget,
                                                     GtkStyle *previous_style);
 static gint                timer_cb                (gpointer data);
@@ -157,8 +157,6 @@ free_all_frames (GnomeAnimator *animator)
 
       if (p->pixmap != NULL)
         gdk_imlib_free_pixmap (p->pixmap);
-      if (p->mask != NULL)
-        gdk_imlib_free_bitmap (p->mask);
 
       pnext = p->next;
       g_free (p);
@@ -890,7 +888,7 @@ gnome_animator_append_frames_from_imlib_at_size (GnomeAnimator *animator,
 
   if (tmp_mask != NULL)
     {
-      gdk_imlib_free_bitmap (tmp_mask);
+      /* Imlib already freed the mask, so don't free it again */
       gdk_gc_unref (mask_gc);
     }
 
