@@ -1,7 +1,7 @@
 
 /* gnome-client.c - GNOME session management client support
  *
- * Copyright (C) 1998 Carsten Schaar
+ * Copyright (C) 1998, 1999 Carsten Schaar
  *
  * Author: Carsten Schaar <nhadcasc@fs-maphy.uni-hannover.de>
  *
@@ -93,16 +93,12 @@ static void   client_unset_config_prefix    (GnomeClient *client);
 
 static gchar** array_init_from_arg           (gint argc, 
 					      gchar *argv[]);
-static gchar** array_copy                    (gchar **source);
-
 
 static GtkObjectClass *parent_class = NULL;
 static gint client_signals[LAST_SIGNAL] = { 0 };
 
 static const char *sm_client_id_arg_name = "--sm-client-id";
 static const char *sm_config_prefix_arg_name = "--sm-config-prefix";
-static const char *sm_client_id_prop="SM_CLIENT_ID";
-
 
 /* The master client.  */
 static GnomeClient *master_client= NULL;
@@ -1142,8 +1138,6 @@ gnome_client_class_init (GnomeClientClass *klass)
 static void
 gnome_client_object_init (GnomeClient *client)
 {
-  struct passwd *pwd;
-
   client->smc_conn          = NULL;
   client->client_id         = NULL;
   client->previous_id       = NULL;
@@ -1369,7 +1363,6 @@ gnome_client_connect (GnomeClient *client)
 
   if (GNOME_CLIENT_CONNECTED (client))
     {
-      IceConn ice_conn;
       gint    restarted= FALSE;
 
       g_free (client->previous_id);
@@ -2598,48 +2591,7 @@ gnome_client_request_save (GnomeClient	       *client,
       g_assert_not_reached ();
       return;
     }
-  
-  if (shutdown) 
-    {
-      static GtkWidget *box = NULL;
-      static GtkWidget *but = NULL;
-      gboolean logout_prompt;
-      
-      gnome_config_push_prefix ("/Gnome/Session/");
-      logout_prompt = gnome_config_get_bool ("Prompt_for_logout=true");
 
-      if(logout_prompt) 
-	{
-	  if(! box) 
-	    {
-	      box = gnome_message_box_new(_("Really log out?"), 
-					  GNOME_MESSAGE_BOX_QUESTION,
-					  GNOME_STOCK_BUTTON_YES, 
-					  GNOME_STOCK_BUTTON_NO, NULL);
-	      gnome_dialog_set_default (GNOME_DIALOG (box), 0);
-	      gtk_window_set_wmclass(GTK_WINDOW(box),
-				     "Logout Dialog", "GnomeUI");
-	      gtk_window_set_policy (GTK_WINDOW (box), FALSE, FALSE, TRUE);
-	      
-	      but = gtk_check_button_new_with_label (_("Ask next time"));
-	      gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (box)->vbox),but,
-				  FALSE, TRUE, GNOME_PAD_SMALL);
-	      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(but),TRUE);
-	      gnome_dialog_close_hides (GNOME_DIALOG (box), TRUE);
-	      gtk_widget_show_all (box);
-	      gdk_window_set_role (GTK_WIDGET(box)->window,
-				   "Gnome Logout Dialog");
-	    }
-	  shutdown = gnome_dialog_run_and_close (GNOME_DIALOG (box)) == 0;
-	  if (GTK_TOGGLE_BUTTON (but)->active != logout_prompt)
-	    {
-	      gnome_config_set_bool("Prompt_for_logout",
-				    GTK_TOGGLE_BUTTON (but)->active);
-	      gnome_config_sync ();
-	    }
-	  gnome_config_pop_prefix ();
-	}
-    }
   if (GNOME_CLIENT_CONNECTED (client))
     {
 #ifdef HAVE_LIBSM
@@ -2776,28 +2728,3 @@ array_init_from_arg (gint argc, gchar *argv[])
 
   return array;
 }
-
-static gchar **
-array_copy (gchar **source)
-{
-  gchar **array;
-  gint    argc;
-  int i, n;
-  
-  if (source == NULL)
-    return NULL;
-
-  /* Count number of elements in source array. */
-  for (n = 0; source[n]; n++) /* */;
-  
-  /* Allocate memory for array. */
-  array = g_new (gchar *, n + 1);
-
-  /* Copy the elements. */
-  for(i = 0; i < n; i++)
-    array[i] = g_strdup(source[i]);
-  
-  array[i] = NULL;
-  
-  return array;
-}
