@@ -161,8 +161,8 @@ typedef struct {
 	/* Whether the user is performing a rubberband selection */
 	guint selecting : 1;
 
-	/* Whether the user clicked on an unselected icon's text */
-	guint select_on_text : 1;
+	/* Whether editing an icon is pending after a button press */
+	guint edit_pending : 1;
 
 	/* Whether selection is pending after a button press */
 	guint select_pending : 1;
@@ -501,12 +501,9 @@ gnome_icon_list_unselect_all (GnomeIconList *gil, GdkEvent *event, gpointer keep
 static void
 sync_selection (Gil *gil, int pos, SyncType type)
 {
-	GilPrivate *priv;
 	GList *list;
 
-	priv = gil->priv;
-
-	for (list = priv->icon_list; list; list = list->next) {
+	for (list = gil->selection; list; list = list->next) {
 		if (GPOINTER_TO_INT (list->data) >= pos) {
 			int i = GPOINTER_TO_INT (list->data);
 
@@ -549,37 +546,40 @@ static gint
 selection_one_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent *event)
 {
 	GilPrivate *priv;
+	GnomeIconTextItem *text;
 	int retval;
-	int do_sel;
 
 	priv = gil->priv;
 	retval = FALSE;
 
+	/* We use a separate variable and ref the object because it may be
+	 * destroyed by one of the signal handlers.
+	 */
+	text = icon->text;
+	gtk_object_ref (GTK_OBJECT (text));
+
 	switch (event->type) {
 	case GDK_BUTTON_PRESS:
+		priv->edit_pending = FALSE;
+		priv->select_pending = FALSE;
+
 		/* Ignore wheel mouse clicks for now */
 		if (event->button.button > 3)
 			break;
 
 		if (!icon->selected) {
 			gnome_icon_list_unselect_all (gil, NULL, NULL);
-
-			if (on_text)
-				priv->select_on_text = TRUE;
-
-			do_sel = TRUE;
+			emit_select (gil, TRUE, idx, event);
 		} else {
 			if (priv->selection_mode == GTK_SELECTION_SINGLE
-			    && (event->button.state & GDK_CONTROL_MASK)) {
-				do_sel = FALSE;
-
-				if (on_text)
-					priv->select_on_text = TRUE;
-			} else
-				do_sel = TRUE;
+			    && (event->button.state & GDK_CONTROL_MASK))
+				emit_select (gil, FALSE, idx, event);
+			else if (on_text && priv->is_editable && event->button.button == 1)
+				priv->edit_pending = TRUE;
+			else
+				emit_select (gil, TRUE, idx, event);
 		}
 
-		emit_select (gil, do_sel, idx, event);
 		retval = TRUE;
 		break;
 
@@ -594,11 +594,12 @@ selection_one_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent *
 		break;
 
 	case GDK_BUTTON_RELEASE:
-		if (on_text && priv->select_on_text) {
-			priv->select_on_text = FALSE;
-			retval = TRUE;
+		if (priv->edit_pending) {
+			gnome_icon_text_item_start_editing (text);
+			priv->edit_pending = FALSE;
 		}
 
+		retval = TRUE;
 		break;
 
 	default:
@@ -609,7 +610,9 @@ selection_one_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent *
 	 * icon text item's own handler from executing.
 	 */
 	if (on_text && retval)
-		gtk_signal_emit_stop_by_name (GTK_OBJECT (icon->text), "event");
+		gtk_signal_emit_stop_by_name (GTK_OBJECT (text), "event");
+
+	gtk_object_unref (GTK_OBJECT (text));
 
 	return retval;
 }
@@ -653,7 +656,7 @@ select_range (Gil *gil, Icon *icon, int idx, GdkEvent *event)
 
 /* Handles icon selection for MULTIPLE or EXTENDED selection modes */
 static void
-do_select_many (Gil *gil, Icon *icon, int idx, GdkEvent *event)
+do_select_many (Gil *gil, Icon *icon, int idx, GdkEvent *event, int use_event)
 {
 	GilPrivate *priv;
 	int range, additive;
@@ -672,14 +675,14 @@ do_select_many (Gil *gil, Icon *icon, int idx, GdkEvent *event)
 
 	if (!range) {
 		if (additive)
-			emit_select (gil, !icon->selected, idx, event);
+			emit_select (gil, !icon->selected, idx, use_event ? event : NULL);
 		else
-			emit_select (gil, TRUE, idx, event);
+			emit_select (gil, TRUE, idx, use_event ? event : NULL);
 
 		priv->last_selected_idx = idx;
 		priv->last_selected_icon = icon;
 	} else
-		select_range (gil, icon, idx, event);
+		select_range (gil, icon, idx, use_event ? event : NULL);
 }
 
 /* Event handler for icons when we are in MULTIPLE or EXTENDED mode */
@@ -687,29 +690,36 @@ static gint
 selection_many_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent *event)
 {
 	GilPrivate *priv;
+	GnomeIconTextItem *text;
 	int retval;
 	int additive, range;
+	int do_select;
 
 	priv = gil->priv;
 	retval = FALSE;
 
+	/* We use a separate variable and ref the object because it may be
+	 * destroyed by one of the signal handlers.
+	 */
+	text = icon->text;
+	gtk_object_ref (GTK_OBJECT (text));
+
 	range = (event->button.state & GDK_SHIFT_MASK) != 0;
 	additive = (event->button.state & GDK_CONTROL_MASK) != 0;
 
 	switch (event->type) {
 	case GDK_BUTTON_PRESS:
+		priv->edit_pending = FALSE;
+		priv->select_pending = FALSE;
+
 		/* Ignore wheel mouse clicks for now */
 		if (event->button.button > 3)
 			break;
 
-		priv->select_pending = FALSE;
+		do_select = TRUE;
 
-		if (!on_text || !icon->selected || additive || range) {
-			if (on_text && (!icon->selected || additive || range))
-				priv->select_on_text = TRUE;
-
-			if ((icon->selected && !additive && !range)
-			    || (additive && !range)) {
+		if (additive || range) {
+			if (additive && !range) {
 				priv->select_pending = TRUE;
 				priv->select_pending_event = *event;
 				priv->select_pending_was_selected = icon->selected;
@@ -718,12 +728,31 @@ selection_many_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent
 				 * know about the click.
 				 */
 				emit_select (gil, TRUE, idx, event);
-			} else
-				do_select_many (gil, icon, idx, event);
+				do_select = FALSE;
+			}
+		} else if (icon->selected) {
+			priv->select_pending = TRUE;
+			priv->select_pending_event = *event;
+			priv->select_pending_was_selected = icon->selected;
 
-			retval = TRUE;
+			if (on_text && priv->is_editable && event->button.button == 1)
+				priv->edit_pending = TRUE;
+
+			emit_select (gil, TRUE, idx, event);
+			do_select = FALSE;
 		}
+#if 0
+		} else if (icon->selected && on_text && priv->is_editable
+			   && event->button.button == 1) {
+			priv->edit_pending = TRUE;
+			do_select = FALSE;
+		}
+#endif
 
+		if (do_select)
+			do_select_many (gil, icon, idx, event, TRUE);
+
+		retval = TRUE;
 		break;
 
 	case GDK_2BUTTON_PRESS:
@@ -737,17 +766,30 @@ selection_many_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent
 		break;
 
 	case GDK_BUTTON_RELEASE:
-		if (on_text && priv->select_on_text) {
-			priv->select_on_text = FALSE;
+		if (priv->select_pending) {
+			icon->selected = priv->select_pending_was_selected;
+			do_select_many (gil, icon, idx, &priv->select_pending_event, FALSE);
+			priv->select_pending = FALSE;
 			retval = TRUE;
 		}
 
+		if (priv->edit_pending) {
+			gnome_icon_text_item_start_editing (text);
+			priv->edit_pending = FALSE;
+			retval = TRUE;
+		}
+#if 0
 		if (priv->select_pending) {
 			icon->selected = priv->select_pending_was_selected;
 			do_select_many (gil, icon, idx, &priv->select_pending_event);
 			priv->select_pending = FALSE;
 			retval = TRUE;
+		} else if (priv->edit_pending) {
+			gnome_icon_text_item_start_editing (text);
+			priv->edit_pending = FALSE;
+			retval = TRUE;
 		}
+#endif
 
 		break;
 
@@ -759,7 +801,9 @@ selection_many_icon_event (Gil *gil, Icon *icon, int idx, int on_text, GdkEvent
 	 * icon text item's own handler from executing.
 	 */
 	if (on_text && retval)
-		gtk_signal_emit_stop_by_name (GTK_OBJECT (icon->text), "event");
+		gtk_signal_emit_stop_by_name (GTK_OBJECT (text), "event");
+
+	gtk_object_unref (GTK_OBJECT (text));
 
 	return retval;
 }
@@ -891,6 +935,10 @@ icon_new_from_imlib (GnomeIconList *gil, GdkImlibImage *im, const char *text)
 		gnome_icon_text_item_get_type (),
 		NULL));
 
+	gnome_canvas_item_set (GNOME_CANVAS_ITEM (icon->text),
+			       "use_broken_event_handling", FALSE,
+			       NULL);
+
 	gnome_icon_text_item_configure (icon->text,
 					0, 0, priv->icon_width, NULL,
 					text, priv->is_editable, priv->static_text);
@@ -1126,13 +1174,14 @@ gnome_icon_list_remove (GnomeIconList *gil, int pos)
 	list = g_list_nth (priv->icon_list, pos);
 	icon = list->data;
 
-	if (icon->text->selected) {
+	if (icon->selected) {
 		was_selected = TRUE;
 
 		switch (priv->selection_mode) {
 		case GTK_SELECTION_SINGLE:
 		case GTK_SELECTION_BROWSE:
 		case GTK_SELECTION_MULTIPLE:
+		case GTK_SELECTION_EXTENDED:
 			gnome_icon_list_unselect_icon (gil, pos);
 			break;
 
@@ -1260,7 +1309,7 @@ select_icon (Gil *gil, int pos, GdkEvent *event)
 		for (list = priv->icon_list; list; list = list->next) {
 			icon = list->data;
 
-			if (i != pos && icon->text->selected)
+			if (i != pos && icon->selected)
 				emit_select (gil, FALSE, i, event);
 
 			i++;
@@ -1270,10 +1319,8 @@ select_icon (Gil *gil, int pos, GdkEvent *event)
 		break;
 
 	case GTK_SELECTION_MULTIPLE:
-		emit_select (gil, TRUE, pos, event);
-		break;
-
 	case GTK_SELECTION_EXTENDED:
+		emit_select (gil, TRUE, pos, event);
 		break;
 
 	default:
@@ -1309,10 +1356,8 @@ unselect_icon (Gil *gil, int pos, GdkEvent *event)
 	case GTK_SELECTION_SINGLE:
 	case GTK_SELECTION_BROWSE:
 	case GTK_SELECTION_MULTIPLE:
-		emit_select (gil, FALSE, pos, event);
-		break;
-
 	case GTK_SELECTION_EXTENDED:
+		emit_select (gil, FALSE, pos, event);
 		break;
 
 	default:
@@ -1495,6 +1540,9 @@ gil_button_press (GtkWidget *widget, GdkEventButton *event)
 	if (only_one)
 		return TRUE;
 
+	if (priv->selecting)
+		return FALSE;
+
 	gnome_canvas_window_to_world (GNOME_CANVAS (gil), event->x, event->y, &tx, &ty);
 	priv->sel_start_x = tx;
 	priv->sel_start_y = ty;
@@ -1518,6 +1566,7 @@ gil_button_press (GtkWidget *widget, GdkEventButton *event)
 
 	gnome_canvas_item_grab (priv->sel_rect, GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 				NULL, event->time);
+
 	return TRUE;
 }
 
@@ -1638,8 +1687,8 @@ gil_button_release (GtkWidget *widget, GdkEventButton *event)
 
 	gnome_canvas_window_to_world (GNOME_CANVAS (gil), event->x, event->y, &x, &y);
 	update_drag_selection (gil, x, y);
-
 	gnome_canvas_item_ungrab (priv->sel_rect, event->time);
+
 	gtk_object_destroy (GTK_OBJECT (priv->sel_rect));
 	priv->sel_rect = NULL;
 	priv->selecting = FALSE;
@@ -1689,7 +1738,6 @@ gil_motion_notify (GtkWidget *widget, GdkEventMotion *event)
 	Gil *gil;
 	GilPrivate *priv;
 	double x, y;
-	int v;
 
 	gil = GIL (widget);
 	priv = gil->priv;
