@@ -80,7 +80,7 @@ gnome_add_gtk_arg_callback(poptContext con,
 {
 	static int gnome_gtk_initialized = FALSE;
 	static GPtrArray *gtk_args = NULL;
-	char *newstr, *newarg;
+	char *newstr;
 	int final_argc;
 	char **final_argv;
 	
@@ -264,6 +264,7 @@ gnome_init_cb(poptContext ctx, enum poptCallbackReason reason,
 }
 
 static const struct poptOption gnome_options[] = {
+        { NULL, '\0', POPT_ARG_INTL_DOMAIN, PACKAGE, 0, NULL, NULL},
 	{NULL, '\0', POPT_ARG_CALLBACK|POPT_CBFLAG_PRE|POPT_CBFLAG_POST,
 	 &gnome_init_cb, 0, NULL, NULL},
 	{"version", 'V', POPT_ARG_NONE, NULL, -1},
