@@ -472,7 +472,7 @@ static void child_list_menu_create (GnomeMDI *mdi, GnomeApp *app)
 		gtk_object_set_data(GTK_OBJECT(item), GNOME_MDI_CHILD_KEY, child->data);
 		gtk_widget_show(item);
 		
-		gtk_menu_shell_insert(GTK_MENU_SHELL(submenu), item, pos);
+		gtk_menu_shell_append(GTK_MENU_SHELL(submenu), item);
 		
 		child = g_list_next(child);
 	}
@@ -535,7 +535,7 @@ void child_list_menu_add_item (GnomeMDI *mdi, GnomeMDIChild *child)
 			gtk_object_set_data(GTK_OBJECT(item), GNOME_MDI_CHILD_KEY, child);
 			gtk_widget_show(item);
 			
-			gtk_menu_shell_insert(GTK_MENU_SHELL(submenu), item, pos);
+			gtk_menu_shell_append(GTK_MENU_SHELL(submenu), item);
 			gtk_widget_queue_resize(submenu);
 		}
 		
@@ -678,7 +678,7 @@ static gint book_button_release (GtkWidget *widget, GdkEventButton *e, gpointer
 
 static GtkWidget *book_create (GnomeMDI *mdi)
 {
-	GtkWidget *us, *rw;
+	GtkWidget *us;
 	
 	us = gtk_notebook_new();
 
@@ -770,8 +770,6 @@ static void app_clone(GnomeMDI *mdi, GnomeApp *app)
 static gint app_close_top (GnomeApp *app, GdkEventAny *event, GnomeMDI *mdi)
 {
 	GnomeMDIChild *child = NULL;
-	GList *child_node;
-	gint handler_ret = TRUE;
 	
 	if(g_list_length(mdi->windows) == 1) {
 		if(!gnome_mdi_remove_all(mdi, FALSE))
@@ -902,6 +900,7 @@ static void app_set_view (GnomeMDI *mdi, GnomeApp *app, GtkWidget *view)
 		}
 	}
 	
+	items = 0;
 	if(view) {
 		child = gnome_mdi_get_child_from_view(view);
 		
@@ -924,7 +923,7 @@ static void app_set_view (GnomeMDI *mdi, GnomeApp *app, GtkWidget *view)
 				( (ui_info = copy_ui_info_tree(child->menu_template)) != NULL) ) {
 				gnome_app_insert_menus_with_data(app, mdi->child_menu_path, ui_info, child);
 				gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_CHILD_MENU_INFO_KEY, ui_info);
-				gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY, GINT_TO_POINTER(count_ui_info_items(ui_info)));
+				items = count_ui_info_items(ui_info);
 			}
 			else {
 				menu_list = child_create_menus(child, view);
@@ -941,17 +940,17 @@ static void app_set_view (GnomeMDI *mdi, GnomeApp *app, GtkWidget *view)
 						items++;
 					}
 					
-					gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY, GINT_TO_POINTER(items));
-					
 					g_list_free(menu_list);
 				}
+				else
+					items = 0;
 			}
 		}
 	}
-	else {
+	else
 		gtk_window_set_title(GTK_WINDOW(app), mdi->title);
-		gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY, NULL);
-	}
+
+	gtk_object_set_data(GTK_OBJECT(app), GNOME_MDI_ITEM_COUNT_KEY, GINT_TO_POINTER(items));
 
 	if(parent)
 		gtk_widget_queue_resize(parent);
@@ -985,8 +984,6 @@ static void app_create (GnomeMDI *mdi, gchar *layout_string)
 {
 	GtkWidget *window;
 	GnomeApp *app;
-	GtkMenuBar *menubar = NULL;
-	GtkToolbar *toolbar = NULL;
 	GtkSignalFunc func = NULL;
 	GnomeUIInfo *ui_info;
 	
@@ -1475,7 +1472,6 @@ gint gnome_mdi_remove_child (GnomeMDI *mdi, GnomeMDIChild *child, gint force)
 gint gnome_mdi_remove_all (GnomeMDI *mdi, gint force)
 {
 	GList *child_node;
-	GnomeMDIChild *child;
 	gint handler_ret = TRUE;
 
 	g_return_val_if_fail(mdi != NULL, FALSE);
@@ -1658,8 +1654,8 @@ void gnome_mdi_set_mode (GnomeMDI *mdi, GnomeMDIMode mode)
 
 			/* if we are to change mode to MODAL, destroy all views except
 			   the active one */
-			if( (mode == GNOME_MDI_MODAL) && (view != mdi->active_view) )
-				gnome_mdi_child_remove_view(child, view);
+			/* if( (mode == GNOME_MDI_MODAL) && (view != mdi->active_view) )
+			   gnome_mdi_child_remove_view(child, view); */
 		}
 		child_node = child_node->next;
 	}
